@@ -2,6 +2,10 @@ from enum import StrEnum, auto
 from typing import Any, Type
 
 from code_insight.code_analysis.abstract import AbstractAnalysis, BaseAnalysisResult
+from code_insight.code_analysis.algorithm import Algorithm
+from code_insight.code_analysis.complexity import Complexity
+from code_insight.code_analysis.readability import Readability
+from code_insight.code_analysis.redundancy import Redundancy
 from code_insight.code_analysis.struct import Struct
 from code_insight.code_analysis.style import Style
 
@@ -11,6 +15,7 @@ class CodeAnalysisType(StrEnum):
     コード解析タイプ
     * スタイル
     * 構造
+    * アルゴリズム
     * 複雑度
     * 冗長度
     * 可読性
@@ -19,6 +24,10 @@ class CodeAnalysisType(StrEnum):
 
     STYLE = auto()
     STRUCT = auto()
+    READABILITY = auto()
+    REDUNDANCY = auto()
+    ALGORITHM = auto()
+    COMPLEXITY = auto()
 
     @staticmethod
     def get_code_analysis_class(type: str) -> AbstractAnalysis[Any]:
@@ -27,6 +36,14 @@ class CodeAnalysisType(StrEnum):
             return Style()
         elif type == CodeAnalysisType.STRUCT:
             return Struct()
+        elif type == CodeAnalysisType.READABILITY:
+            return Readability()
+        elif type == CodeAnalysisType.REDUNDANCY:
+            return Redundancy()
+        elif type == CodeAnalysisType.ALGORITHM:
+            return Algorithm()
+        elif type == CodeAnalysisType.COMPLEXITY:
+            return Complexity()
         else:
             raise ValueError(f"Invalid code analysis type: {type}")
 
@@ -36,6 +53,10 @@ class CodeAnalysis:
 
     source_code: str
 
+    def __init__(self, source_code: str) -> None:
+        """コンストラクタ"""
+        self.source_code = source_code
+
     def analyze(
         self, types: list[CodeAnalysisType]
     ) -> dict[CodeAnalysisType, Type[BaseAnalysisResult]]:
